<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://erezbentovim.com
 * @since             1.0.0
 * @package           Rtl_Support_For_Oxygen_Builder
 *
 * @wordpress-plugin
 * Plugin Name:       RTL support for Oxygen Builder
 * Plugin URI:        https://github.com/erezbt
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.0.0
 * Author:            Erez Ben Tovim
 * Author URI:        https://erezbentovim.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       rtl-support-for-oxygen-builder
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'RTL_SUPPORT_FOR_OXYGEN_BUILDER_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-rtl-support-for-oxygen-builder-activator.php
 */
function activate_rtl_support_for_oxygen_builder() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-rtl-support-for-oxygen-builder-activator.php';
	Rtl_Support_For_Oxygen_Builder_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-rtl-support-for-oxygen-builder-deactivator.php
 */
function deactivate_rtl_support_for_oxygen_builder() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-rtl-support-for-oxygen-builder-deactivator.php';
	Rtl_Support_For_Oxygen_Builder_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_rtl_support_for_oxygen_builder' );
register_deactivation_hook( __FILE__, 'deactivate_rtl_support_for_oxygen_builder' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-rtl-support-for-oxygen-builder.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_rtl_support_for_oxygen_builder() {

	$plugin = new Rtl_Support_For_Oxygen_Builder();
	$plugin->run();

}
run_rtl_support_for_oxygen_builder();
